==> DateTime-Locale-1.37.tar.gz: DateTime-Locale-1.37/share/ca-IT.pl <==
{
  am_pm_abbreviated => [
    "a.\N{U+202f}m.",
    "p.\N{U+202f}m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E H:mm",
    EHms => "E H:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "LLL y G",
    GyMMMEd => "E, d MMM 'de' y G",
    GyMMMM => "LLLL 'de' y G",
    GyMMMMEd => "E, d MMMM 'de' y G",
    GyMMMMd => "d MMMM 'de' y G",
    GyMMMd => "d MMM 'de' y G",
    GyMd => "dd-MM-y GGGGG",
    H => "H",
    Hm => "H:mm",
    Hms => "H:mm:ss",
    Hmsv => "H:mm:ss v",
    Hmsvvvv => "H:mm:ss (vvvv)",
    Hmv => "H:mm v",
    Hmvvvv => "H:mm (vvvv)",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-one" => "'setmana' W MMMM",
    "MMMMW-count-other" => "'setmana' W MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmsvvvv => "h:mm:ss\N{U+202f}a (vvvv)",
    hmv => "h:mm\N{U+202f}a v",
    hmvvvv => "h:mm\N{U+202f}a (vvvv)",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "LLL 'de' y",
    yMMMEd => "E, d MMM y",
    yMMMM => "LLLL 'de' y",
    yMMMMEd => "E, d MMMM 'de' y",
    yMMMMd => "d MMMM 'de' y",
    yMMMd => "d MMM 'de' y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'setmana' w 'de' Y",
    "yw-count-other" => "'setmana' w 'de' Y",
  },
  code => "ca-IT",
  date_format_full => "EEEE, d MMMM 'de' y",
  date_format_long => "d MMMM 'de' y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "dl.",
    "dt.",
    "dc.",
    "dj.",
    "dv.",
    "ds.",
    "dg.",
  ],
  day_format_narrow => [
    "dl",
    "dt",
    "dc",
    "dj",
    "dv",
    "ds",
    "dg",
  ],
  day_format_wide => [
    "dilluns",
    "dimarts",
    "dimecres",
    "dijous",
    "divendres",
    "dissabte",
    "diumenge",
  ],
  day_stand_alone_abbreviated => [
    "dl.",
    "dt.",
    "dc.",
    "dj.",
    "dv.",
    "ds.",
    "dg.",
  ],
  day_stand_alone_narrow => [
    "dl",
    "dt",
    "dc",
    "dj",
    "dv",
    "ds",
    "dg",
  ],
  day_stand_alone_wide => [
    "dilluns",
    "dimarts",
    "dimecres",
    "dijous",
    "divendres",
    "dissabte",
    "diumenge",
  ],
  era_abbreviated => [
    "aC",
    "dC",
  ],
  era_narrow => [
    "aC",
    "dC",
  ],
  era_wide => [
    "abans de Crist",
    "despr\N{U+00e9}s de Crist",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Catalan",
  month_format_abbreviated => [
    "de gen.",
    "de febr.",
    "de mar\N{U+00e7}",
    "d\N{U+2019}abr.",
    "de maig",
    "de juny",
    "de jul.",
    "d\N{U+2019}ag.",
    "de set.",
    "d\N{U+2019}oct.",
    "de nov.",
    "de des.",
  ],
  month_format_narrow => [
    "GN",
    "FB",
    "M\N{U+00c7}",
    "AB",
    "MG",
    "JN",
    "JL",
    "AG",
    "ST",
    "OC",
    "NV",
    "DS",
  ],
  month_format_wide => [
    "de gener",
    "de febrer",
    "de mar\N{U+00e7}",
    "d\N{U+2019}abril",
    "de maig",
    "de juny",
    "de juliol",
    "d\N{U+2019}agost",
    "de setembre",
    "d\N{U+2019}octubre",
    "de novembre",
    "de desembre",
  ],
  month_stand_alone_abbreviated => [
    "gen.",
    "febr.",
    "mar\N{U+00e7}",
    "abr.",
    "maig",
    "juny",
    "jul.",
    "ag.",
    "set.",
    "oct.",
    "nov.",
    "des.",
  ],
  month_stand_alone_narrow => [
    "GN",
    "FB",
    "M\N{U+00c7}",
    "AB",
    "MG",
    "JN",
    "JL",
    "AG",
    "ST",
    "OC",
    "NV",
    "DS",
  ],
  month_stand_alone_wide => [
    "gener",
    "febrer",
    "mar\N{U+00e7}",
    "abril",
    "maig",
    "juny",
    "juliol",
    "agost",
    "setembre",
    "octubre",
    "novembre",
    "desembre",
  ],
  name => "Catalan Italy",
  native_language => "catal\N{U+00e0}",
  native_name => "catal\N{U+00e0} It\N{U+00e0}lia",
  native_script => undef,
  native_territory => "It\N{U+00e0}lia",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1T",
    "2T",
    "3T",
    "4T",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1r trimestre",
    "2n trimestre",
    "3r trimestre",
    "4t trimestre",
  ],
  quarter_stand_alone_abbreviated => [
    "1T",
    "2T",
    "3T",
    "4T",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1r trimestre",
    "2n trimestre",
    "3r trimestre",
    "4t trimestre",
  ],
  script => undef,
  territory => "Italy",
  time_format_full => "H:mm:ss (zzzz)",
  time_format_long => "H:mm:ss z",
  time_format_medium => "H:mm:ss",
  time_format_short => "H:mm",
  variant => undef,
  version => 42,
}

==> DateTime-Locale-1.41.tar.gz: DateTime-Locale-1.41/share/ca-IT.pl <==
{
  am_pm_abbreviated => [
    "a.\N{U+202f}m.",
    "p.\N{U+202f}m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E H:mm",
    EHms => "E H:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "LLL y G",
    GyMMMEd => "E, d MMM 'del' y G",
    GyMMMM => "LLLL 'del' y G",
    GyMMMMEd => "E, d MMMM 'del' y G",
    GyMMMMd => "d MMMM 'del' y G",
    GyMMMd => "d MMM 'del' y G",
    GyMd => "dd-MM-y GGGGG",
    H => "H",
    Hm => "H:mm",
    Hms => "H:mm:ss",
    Hmsv => "H:mm:ss v",
    Hmsvvvv => "H:mm:ss (vvvv)",
    Hmv => "H:mm v",
    Hmvvvv => "H:mm (vvvv)",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    MMMMEd => "E, d MMMM",
    "MMMMW-count-one" => "'setmana' W MMMM",
    "MMMMW-count-other" => "'setmana' W MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmsvvvv => "h:mm:ss\N{U+202f}a (vvvv)",
    hmv => "h:mm\N{U+202f}a v",
    hmvvvv => "h:mm\N{U+202f}a (vvvv)",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "LLL 'del' y",
    yMMMEd => "E, d MMM y",
    yMMMM => "LLLL 'del' y",
    yMMMMEd => "E, d MMMM 'del' y",
    yMMMMd => "d MMMM 'del' y",
    yMMMd => "d MMM 'del' y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'setmana' w 'del' Y",
    "yw-count-other" => "'setmana' w 'del' Y",
  },
  code => "ca-IT",
  date_format_full => "EEEE, d MMMM 'del' y",
  date_format_long => "d MMMM 'del' y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "dl.",
    "dt.",
    "dc.",
    "dj.",
    "dv.",
    "ds.",
    "dg.",
  ],
  day_format_narrow => [
    "dl.",
    "dt.",
    "dc.",
    "dj.",
    "dv.",
    "ds.",
    "dg.",
  ],
  day_format_wide => [
    "dilluns",
    "dimarts",
    "dimecres",
    "dijous",
    "divendres",
    "dissabte",
    "diumenge",
  ],
  day_stand_alone_abbreviated => [
    "dl.",
    "dt.",
    "dc.",
    "dj.",
    "dv.",
    "ds.",
    "dg.",
  ],
  day_stand_alone_narrow => [
    "dl.",
    "dt.",
    "dc.",
    "dj.",
    "dv.",
    "ds.",
    "dg.",
  ],
  day_stand_alone_wide => [
    "dilluns",
    "dimarts",
    "dimecres",
    "dijous",
    "divendres",
    "dissabte",
    "diumenge",
  ],
  era_abbreviated => [
    "aC",
    "dC",
  ],
  era_narrow => [
    "aC",
    "dC",
  ],
  era_wide => [
    "abans de Crist",
    "despr\N{U+00e9}s de Crist",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Catalan",
  month_format_abbreviated => [
    "de gen.",
    "de febr.",
    "de mar\N{U+00e7}",
    "d\N{U+2019}abr.",
    "de maig",
    "de juny",
    "de jul.",
    "d\N{U+2019}ag.",
    "de set.",
    "d\N{U+2019}oct.",
    "de nov.",
    "de des.",
  ],
  month_format_narrow => [
    "GN",
    "FB",
    "M\N{U+00c7}",
    "AB",
    "MG",
    "JN",
    "JL",
    "AG",
    "ST",
    "OC",
    "NV",
    "DS",
  ],
  month_format_wide => [
    "de gener",
    "de febrer",
    "de mar\N{U+00e7}",
    "d\N{U+2019}abril",
    "de maig",
    "de juny",
    "de juliol",
    "d\N{U+2019}agost",
    "de setembre",
    "d\N{U+2019}octubre",
    "de novembre",
    "de desembre",
  ],
  month_stand_alone_abbreviated => [
    "gen.",
    "febr.",
    "mar\N{U+00e7}",
    "abr.",
    "maig",
    "juny",
    "jul.",
    "ag.",
    "set.",
    "oct.",
    "nov.",
    "des.",
  ],
  month_stand_alone_narrow => [
    "GN",
    "FB",
    "M\N{U+00c7}",
    "AB",
    "MG",
    "JN",
    "JL",
    "AG",
    "ST",
    "OC",
    "NV",
    "DS",
  ],
  month_stand_alone_wide => [
    "gener",
    "febrer",
    "mar\N{U+00e7}",
    "abril",
    "maig",
    "juny",
    "juliol",
    "agost",
    "setembre",
    "octubre",
    "novembre",
    "desembre",
  ],
  name => "Catalan Italy",
  native_language => "catal\N{U+00e0}",
  native_name => "catal\N{U+00e0} It\N{U+00e0}lia",
  native_script => undef,
  native_territory => "It\N{U+00e0}lia",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1T",
    "2T",
    "3T",
    "4T",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1r trimestre",
    "2n trimestre",
    "3r trimestre",
    "4t trimestre",
  ],
  quarter_stand_alone_abbreviated => [
    "1T",
    "2T",
    "3T",
    "4T",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1r trimestre",
    "2n trimestre",
    "3r trimestre",
    "4t trimestre",
  ],
  script => undef,
  territory => "Italy",
  time_format_full => "H:mm:ss (zzzz)",
  time_format_long => "H:mm:ss z",
  time_format_medium => "H:mm:ss",
  time_format_short => "H:mm",
  variant => undef,
  version => "44.1",
}
